Enum ArchiveFormat
pub enum ArchiveFormat {
Tar,
Zip,
SevenZip,
Cpio,
Ar,
Iso,
Rar,
Cab,
Warc,
Mtree,
Unknown,
}Expand description
Archive container formats.
Variants
Tar
POSIX tar archive.
Zip
ZIP archive.
SevenZip
7z archive.
Cpio
CPIO archive.
Ar
Unix ar archive.
Iso
ISO image.
Rar
RAR archive.
Cab
Microsoft Cabinet archive.
Warc
WARC or ARC web archive.
Mtree
mtree manifest.
Unknown
Unknown or intentionally unspecified archive format.
Implementations
impl ArchiveFormat
impl ArchiveFormat
pub const fn extension(self) -> Option<&'static str>
pub const fn extension(self) -> Option<&'static str>
Returns the most common file extension for this archive format.
pub fn from_label(input: &str) -> ArchiveFormat
pub fn from_label(input: &str) -> ArchiveFormat
Parses a stable format label.
pub fn from_extension(input: &str) -> ArchiveFormat
pub fn from_extension(input: &str) -> ArchiveFormat
Detects an archive format from a filename or extension.