Struct ArchiveEntry
pub struct ArchiveEntry {
pub path: String,
pub kind: ArchiveEntryKind,
pub size: Option<u64>,
pub mode: Option<u32>,
pub modified_unix_seconds: Option<i64>,
}Expand description
Generic archive entry metadata.
Fields
path: StringArchive-internal path.
kind: ArchiveEntryKindArchive entry kind.
size: Option<u64>Entry payload size in bytes, when known.
mode: Option<u32>Entry mode or permission bits, when known.
modified_unix_seconds: Option<i64>Unix timestamp seconds for the modified time, when known.
Implementations
impl ArchiveEntry
impl ArchiveEntry
pub fn new(path: impl Into<String>, kind: ArchiveEntryKind) -> ArchiveEntry
pub fn new(path: impl Into<String>, kind: ArchiveEntryKind) -> ArchiveEntry
Creates archive entry metadata from a path and kind.
pub fn file(path: impl Into<String>) -> ArchiveEntry
pub fn file(path: impl Into<String>) -> ArchiveEntry
Creates a regular file entry.
pub fn directory(path: impl Into<String>) -> ArchiveEntry
pub fn directory(path: impl Into<String>) -> ArchiveEntry
Creates a directory entry.
pub fn symlink(path: impl Into<String>) -> ArchiveEntry
pub fn symlink(path: impl Into<String>) -> ArchiveEntry
Creates a symbolic link entry.
pub const fn with_size(self, size: u64) -> ArchiveEntry
pub const fn with_size(self, size: u64) -> ArchiveEntry
Adds known entry size metadata.
pub const fn with_mode(self, mode: u32) -> ArchiveEntry
pub const fn with_mode(self, mode: u32) -> ArchiveEntry
Adds known entry mode metadata.
pub const fn with_modified_unix_seconds(self, seconds: i64) -> ArchiveEntry
pub const fn with_modified_unix_seconds(self, seconds: i64) -> ArchiveEntry
Adds known modified timestamp metadata.
pub const fn kind(&self) -> ArchiveEntryKind
pub const fn kind(&self) -> ArchiveEntryKind
Returns the archive entry kind.
pub const fn modified_unix_seconds(&self) -> Option<i64>
pub const fn modified_unix_seconds(&self) -> Option<i64>
Returns the known modified timestamp.
pub const fn is_directory(&self) -> bool
pub const fn is_directory(&self) -> bool
Returns whether this is a directory entry.
pub const fn is_symlink(&self) -> bool
pub const fn is_symlink(&self) -> bool
Returns whether this is a symbolic link entry.