BioAlphabet

Struct BioAlphabet 

pub struct BioAlphabet { /* private fields */ }
A biological alphabet with a descriptive kind and symbol set.

Implementations

Source

impl BioAlphabet

pub const fn new(kind: AlphabetKind, symbols: AlphabetSymbolSet) -> Self

Creates an alphabet from a kind and symbol set.

pub fn dna() -> Self

Returns the simple DNA alphabet A, C, G, T.

pub fn rna() -> Self

Returns the simple RNA alphabet A, C, G, U.

pub fn protein() -> Self

Returns the common protein alphabet.

pub fn dna_with_ambiguity() -> Self

Returns a DNA alphabet including common ambiguity symbols.

pub fn rna_with_ambiguity() -> Self

Returns an RNA alphabet including common ambiguity symbols.

pub fn protein_with_ambiguity() -> Self

Returns a protein alphabet including common ambiguity symbols.

pub fn custom( kind: impl Into<String>, symbols: impl AsRef<str>, ) -> Result<Self, AlphabetError>

Creates a custom alphabet.

Errors

Returns AlphabetError::EmptySymbolSet when no symbols are supplied.

pub const fn kind(&self) -> &AlphabetKind

Returns the descriptive alphabet kind.

pub const fn symbols(&self) -> &AlphabetSymbolSet

Returns the alphabet symbols.

pub fn contains(&self, symbol: char) -> bool

Returns true when the symbol is present in the alphabet.

pub fn contains_all(&self, text: impl AsRef<str>) -> bool

Returns true when every character in the supplied text is present in the alphabet.