isotope_by_symbol

Function isotope_by_symbol 

pub fn isotope_by_symbol(symbol: &str, mass_number: u16) -> Option<Isotope>
Creates an isotope identity from an element symbol and mass number.

Symbol lookup trims surrounding whitespace and compares symbols with ASCII case-insensitive matching through use-element.