ReactionEntry

Struct ReactionEntry 

pub struct ReactionEntry { /* private fields */ }
A stoichiometric entry on one side of a reaction.

Implementations

Source

impl ReactionEntry

pub fn new( coefficient: StoichiometricCoefficient, formula: ChemicalFormula, side: ReactionSide, ) -> Result<ReactionEntry, StoichiometryValidationError>

Creates a reaction entry.

Errors

Returns StoichiometryValidationError::ZeroCoefficient if the coefficient is structurally invalid.

pub fn from_value( coefficient: u32, formula: ChemicalFormula, side: ReactionSide, ) -> Result<ReactionEntry, StoichiometryValidationError>

Creates a reaction entry from a raw coefficient value.

Errors

Returns StoichiometryValidationError::ZeroCoefficient when coefficient is zero.

pub const fn coefficient(&self) -> StoichiometricCoefficient

Returns the coefficient.

pub const fn formula(&self) -> &ChemicalFormula

Returns the formula.

pub const fn side(&self) -> ReactionSide

Returns the reaction side.

pub const fn term(&self) -> &StoichiometricTerm

Returns the stoichiometric term.

pub fn into_parts( self, ) -> (StoichiometricCoefficient, ChemicalFormula, ReactionSide)

Consumes the entry and returns its parts.