pub struct ReactionTerm { /* private fields */ }Expand description
A formula-backed reaction term with a stoichiometric coefficient.
Implementations
Sourceimpl ReactionTerm
impl ReactionTerm
Sourcepub fn new(formula: ChemicalFormula) -> ReactionTerm
pub fn new(formula: ChemicalFormula) -> ReactionTerm
Creates a reaction term with coefficient one.
Sourcepub fn from_parts(
coefficient: StoichiometricCoefficient,
formula: ChemicalFormula,
) -> Result<ReactionTerm, ReactionValidationError>
pub fn from_parts( coefficient: StoichiometricCoefficient, formula: ChemicalFormula, ) -> Result<ReactionTerm, ReactionValidationError>
Creates a reaction term from validated parts.
Errors
Returns ReactionValidationError::InvalidStoichiometry if the stoichiometry primitive
rejects the coefficient.
Sourcepub fn from_value(
coefficient: u32,
formula: ChemicalFormula,
) -> Result<ReactionTerm, ReactionValidationError>
pub fn from_value( coefficient: u32, formula: ChemicalFormula, ) -> Result<ReactionTerm, ReactionValidationError>
Creates a reaction term from a raw coefficient value.
Errors
Returns ReactionValidationError::InvalidStoichiometry when coefficient is zero.
Sourcepub fn with_coefficient(
self,
coefficient: u32,
) -> Result<ReactionTerm, ReactionValidationError>
pub fn with_coefficient( self, coefficient: u32, ) -> Result<ReactionTerm, ReactionValidationError>
Returns a copy of this term with a new coefficient.
Errors
Returns ReactionValidationError::InvalidStoichiometry when coefficient is zero.
Sourcepub const fn coefficient(&self) -> StoichiometricCoefficient
pub const fn coefficient(&self) -> StoichiometricCoefficient
Returns the stoichiometric coefficient.
Sourcepub const fn formula(&self) -> &ChemicalFormula
pub const fn formula(&self) -> &ChemicalFormula
Returns the chemical formula.
Sourcepub const fn as_stoichiometric_term(&self) -> &StoichiometricTerm
pub const fn as_stoichiometric_term(&self) -> &StoichiometricTerm
Returns the wrapped stoichiometric term.
Sourcepub fn into_stoichiometric_term(self) -> StoichiometricTerm
pub fn into_stoichiometric_term(self) -> StoichiometricTerm
Consumes this value and returns the wrapped stoichiometric term.
Sourcepub fn into_parts(self) -> (StoichiometricCoefficient, ChemicalFormula)
pub fn into_parts(self) -> (StoichiometricCoefficient, ChemicalFormula)
Consumes the term and returns its parts.