Ion

Struct Ion 

pub struct Ion { /* private fields */ }
A charged atom or charged group represented by formula and charge.

Implementations

Source

impl Ion

pub fn new(formula: ChemicalFormula, charge: IonCharge) -> Self

Creates an ion from a parsed formula and validated charge.

pub fn formula(&self) -> &ChemicalFormula

Returns the chemical formula.

pub const fn ion_formula(&self) -> &IonFormula

Returns the ion formula wrapper.

pub const fn charge(&self) -> IonCharge

Returns the ionic charge.

pub const fn name(&self) -> Option<&IonName>

Returns the optional ion name.

pub fn kinds(&self) -> &[IonKind]

Returns ion kind labels in insertion order.

pub fn oxidation_state_label(&self) -> Option<&str>

Returns the optional oxidation-state label.

pub const fn is_cation(&self) -> bool

Returns true when the ion has a positive charge.

pub const fn is_anion(&self) -> bool

Returns true when the ion has a negative charge.

pub fn with_kind(self, kind: IonKind) -> Self

Adds a kind label if it is not already present.

pub fn with_name(self, name: IonName) -> Self

Sets the ion name from a validated value.

pub fn try_with_name(self, name: &str) -> Result<Self, IonValidationError>

Sets the ion name after validation.

Errors

Returns IonValidationError::EmptyName when name is empty after trimming.

pub fn with_oxidation_state_label(self, label: String) -> Self

Sets the oxidation-state label from a prevalidated value.

pub fn try_with_oxidation_state_label( self, label: &str, ) -> Result<Self, IonValidationError>

Sets the oxidation-state label after validation.

Errors

Returns IonValidationError::EmptyOxidationStateLabel when label is empty after trimming.