MonatomicIon

Struct MonatomicIon 

pub struct MonatomicIon(/* private fields */);
A monatomic ion wrapper.

Implementations

Source

impl MonatomicIon

pub fn new( formula: ChemicalFormula, charge: IonCharge, ) -> Result<Self, IonValidationError>

Creates a monatomic ion from a formula and charge.

Errors

Returns IonValidationError::ExpectedMonatomicFormula when formula does not contain exactly one atom.

pub fn from_ion(ion: Ion) -> Result<Self, IonValidationError>

Wraps an existing ion after monatomic formula validation.

Errors

Returns IonValidationError::ExpectedMonatomicFormula when the ion formula does not contain exactly one atom.

pub const fn as_ion(&self) -> &Ion

Returns the wrapped ion.

pub fn into_ion(self) -> Ion

Consumes the wrapper and returns the ion.