PolyatomicIon

Struct PolyatomicIon 

pub struct PolyatomicIon(/* private fields */);
A polyatomic ion wrapper.

Implementations

Source

impl PolyatomicIon

pub fn new( formula: ChemicalFormula, charge: IonCharge, ) -> Result<Self, IonValidationError>

Creates a polyatomic ion from a formula and charge.

Errors

Returns IonValidationError::ExpectedPolyatomicFormula when formula does not contain more than one atom.

pub fn from_ion(ion: Ion) -> Result<Self, IonValidationError>

Wraps an existing ion after polyatomic formula validation.

Errors

Returns IonValidationError::ExpectedPolyatomicFormula when the ion formula does not contain more than one atom.

pub const fn as_ion(&self) -> &Ion

Returns the wrapped ion.

pub fn into_ion(self) -> Ion

Consumes the wrapper and returns the ion.