pub const fn is_valid_isotope_numbers(
atomic_number: u8,
mass_number: u16,
) -> boolExpand description
Returns true when the isotope numbers are structurally valid.
This only checks that atomic_number is between 1 and 118 inclusive and that
mass_number >= atomic_number. It does not imply that the isotope is known,
stable, naturally occurring, or abundant.