MolarMassValidationError

Enum MolarMassValidationError 

pub enum MolarMassValidationError {
    NonFiniteMolarMass,
    NonPositiveMolarMass,
    InvalidElementSymbol(String),
    NonFiniteAtomicMass {
        symbol: String,
    },
    NonPositiveAtomicMass {
        symbol: String,
    },
    ZeroElementCount {
        symbol: String,
    },
    FormulaCountTooLarge {
        symbol: String,
        count: u64,
    },
    MissingAtomicMass {
        symbol: String,
    },
}
Errors returned while constructing or calculating molar mass values.

Variants



NonFiniteMolarMass

A molar mass value was not finite.



NonPositiveMolarMass

A molar mass value was zero or negative.



InvalidElementSymbol(String)

An element symbol does not match the supported chemical-formula shape.



NonFiniteAtomicMass

An atomic mass value was not finite.

Fields

symbol: String


NonPositiveAtomicMass

An atomic mass value was zero or negative.

Fields

symbol: String


ZeroElementCount

An expanded formula count was zero.

Fields

symbol: String


FormulaCountTooLarge

An expanded formula count cannot fit the contribution count type.

Fields

symbol: String
count: u64


MissingAtomicMass

No atomic mass entry exists for a required element symbol.

Fields

symbol: String