MolarMassCalculation

Struct MolarMassCalculation 

pub struct MolarMassCalculation { /* private fields */ }
A formula and atomic-mass lookup ready for molar-mass calculation.

Implementations

Source

impl MolarMassCalculation

pub const fn new(formula: ChemicalFormula, lookup: AtomicMassLookup) -> Self

Creates a calculation from a formula and explicit lookup table.

pub fn with_standard_atomic_masses( formula: ChemicalFormula, ) -> Result<Self, MolarMassValidationError>

Creates a calculation using the RustUse standard atomic-mass table.

Errors

Returns a molar-mass validation error if any formula element is missing from the RustUse atomic-mass table.

pub const fn formula(&self) -> &ChemicalFormula

Returns the source formula.

pub const fn lookup(&self) -> &AtomicMassLookup

Returns the atomic-mass lookup table.

pub fn calculate(&self) -> Result<FormulaMolarMass, MolarMassValidationError>

Calculates the formula molar mass.

Errors

Returns a structured molar-mass validation error when a formula count is invalid, a count cannot be represented, an atomic mass is missing, or the calculated molar mass is invalid.