pub struct PercentYield(/* private fields */);Expand description
A nonnegative finite percent yield value.
Implementations
Sourceimpl PercentYield
impl PercentYield
Sourcepub fn new(value: f64) -> Result<Self, StoichiometryValidationError>
pub fn new(value: f64) -> Result<Self, StoichiometryValidationError>
Creates a percent yield value.
Errors
Returns StoichiometryValidationError::NonFiniteYield when value is not
finite, or StoichiometryValidationError::NegativeYield when it is negative.
Sourcepub fn from_actual_and_theoretical(
actual: f64,
theoretical: f64,
) -> Result<Self, StoichiometryValidationError>
pub fn from_actual_and_theoretical( actual: f64, theoretical: f64, ) -> Result<Self, StoichiometryValidationError>
Calculates percent yield from actual and theoretical yield values.
Errors
Returns a validation error when either yield value is invalid, or when the theoretical yield is zero or negative.
Sourcepub fn from_yields(
actual: ActualYield,
theoretical: TheoreticalYield,
) -> Result<Self, StoichiometryValidationError>
pub fn from_yields( actual: ActualYield, theoretical: TheoreticalYield, ) -> Result<Self, StoichiometryValidationError>
Calculates percent yield from validated yield wrappers.
Errors
Returns StoichiometryValidationError::NonFiniteYield if the calculated percent
yield is not finite.