pub struct ReactionEntry { /* private fields */ }Expand description
A stoichiometric entry on one side of a reaction.
Implementations
Sourceimpl ReactionEntry
impl ReactionEntry
Sourcepub fn new(
coefficient: StoichiometricCoefficient,
formula: ChemicalFormula,
side: ReactionSide,
) -> Result<Self, StoichiometryValidationError>
pub fn new( coefficient: StoichiometricCoefficient, formula: ChemicalFormula, side: ReactionSide, ) -> Result<Self, StoichiometryValidationError>
Creates a reaction entry.
Errors
Returns StoichiometryValidationError::ZeroCoefficient if the coefficient is
structurally invalid.
Sourcepub fn from_value(
coefficient: u32,
formula: ChemicalFormula,
side: ReactionSide,
) -> Result<Self, StoichiometryValidationError>
pub fn from_value( coefficient: u32, formula: ChemicalFormula, side: ReactionSide, ) -> Result<Self, StoichiometryValidationError>
Creates a reaction entry from a raw coefficient value.
Errors
Returns StoichiometryValidationError::ZeroCoefficient when coefficient is zero.
Sourcepub const fn coefficient(&self) -> StoichiometricCoefficient
pub const fn coefficient(&self) -> StoichiometricCoefficient
Returns the coefficient.
Sourcepub const fn side(&self) -> ReactionSide
pub const fn side(&self) -> ReactionSide
Returns the reaction side.
Sourcepub const fn term(&self) -> &StoichiometricTerm
pub const fn term(&self) -> &StoichiometricTerm
Returns the stoichiometric term.
Sourcepub fn into_parts(
self,
) -> (StoichiometricCoefficient, ChemicalFormula, ReactionSide)
pub fn into_parts( self, ) -> (StoichiometricCoefficient, ChemicalFormula, ReactionSide)
Consumes the entry and returns its parts.