CliOption

Struct CliOption 

pub struct CliOption { /* private fields */ }
A primitive command-line key/value option.

Implementations



impl CliOption

pub const fn new(name: CliOptionName, value: OptionValue) -> CliOption

Creates a CLI option from an already validated name and owned value.

pub fn from_name_value( name: &str, value: impl Into<String>, ) -> Result<CliOption, CliOptionError>

Creates a CLI option from a name and value pair, such as --key value.

Errors

Returns [CliOptionError] when name is not a valid option name.

pub fn from_equals_token(token: &str) -> Result<CliOption, CliOptionError>

Creates a CLI option from a token like --key=value.

Errors

Returns [CliOptionError] when the token does not use --key=value form.

pub const fn name(&self) -> &CliOptionName

Returns the option name.

pub const fn value(&self) -> &OptionValue

Returns the option value.

pub fn to_equals_token(&self) -> String

Returns the --key=value token form.