Enum AchTransactionCode
pub enum AchTransactionCode {
CheckingCredit,
CheckingPrenoteCredit,
CheckingDebit,
CheckingPrenoteDebit,
SavingsCredit,
SavingsPrenoteCredit,
SavingsDebit,
SavingsPrenoteDebit,
LoanCredit,
LoanPrenoteCredit,
}Expand description
Conservative ACH transaction-code vocabulary.
Variants
CheckingCredit
Credit destined for a checking account.
CheckingPrenoteCredit
Prenotification credit destined for a checking account.
CheckingDebit
Debit destined for a checking account.
CheckingPrenoteDebit
Prenotification debit destined for a checking account.
SavingsCredit
Credit destined for a savings account.
SavingsPrenoteCredit
Prenotification credit destined for a savings account.
SavingsDebit
Debit destined for a savings account.
SavingsPrenoteDebit
Prenotification debit destined for a savings account.
LoanCredit
Credit destined for a loan account.
LoanPrenoteCredit
Prenotification credit destined for a loan account.
Implementations
impl AchTransactionCode
impl AchTransactionCode
pub const fn from_code(code: u8) -> Result<AchTransactionCode, AchError>
pub const fn from_code(code: u8) -> Result<AchTransactionCode, AchError>
Creates a transaction code from a numeric NACHA transaction code.
Errors
Returns AchError::InvalidTransactionCode when the code is not in this crate’s
conservative transaction-code vocabulary.
pub const fn account_type(self) -> AchAccountType
pub const fn account_type(self) -> AchAccountType
Returns the account type implied by the transaction code.
pub const fn direction(self) -> AchEntryDirection
pub const fn direction(self) -> AchEntryDirection
Returns the direction implied by the transaction code.
pub const fn is_prenote(self) -> bool
pub const fn is_prenote(self) -> bool
Returns whether the transaction code is a prenotification code.