Enum IbanError
pub enum IbanError {
Empty,
InvalidLength,
InvalidCountryCode,
InvalidCheckDigits,
InvalidCharacter,
UnsupportedCountryCode,
InvalidCountryLength,
InvalidChecksum,
}Expand description
Errors returned while constructing IBAN values.
Variants
Empty
The input was empty after trimming whitespace and spaces.
InvalidLength
The compact IBAN was shorter than four characters or longer than 34 characters.
InvalidCountryCode
The country code was not two uppercase ASCII letters.
InvalidCheckDigits
The check digits were not two ASCII digits.
InvalidCharacter
The IBAN contained a character other than an ASCII letter, digit, or space.
UnsupportedCountryCode
The country code is not present in the static IBAN length table.
InvalidCountryLength
The compact IBAN length did not match the country-specific IBAN length.
InvalidChecksum
The standard mod-97 checksum failed.