pub struct FileTrailerRecord { /* private fields */ }Expand description
BAI2 file trailer record.
Implementations
Sourceimpl FileTrailerRecord
impl FileTrailerRecord
Sourcepub const fn file_control_total(&self) -> Option<i128>
pub const fn file_control_total(&self) -> Option<i128>
Returns the optional file control total.
Sourcepub const fn group_count(&self) -> Option<usize>
pub const fn group_count(&self) -> Option<usize>
Returns the optional group count.
Sourcepub const fn record_count(&self) -> Option<usize>
pub const fn record_count(&self) -> Option<usize>
Returns the optional record count.
Sourcepub const fn validate_record_count(
&self,
actual: usize,
) -> Result<(), Bai2Error>
pub const fn validate_record_count( &self, actual: usize, ) -> Result<(), Bai2Error>
Validates a parsed logical record count against the trailer record count when present.
Errors
Returns Bai2Error::InvalidCount when the expected count is present and differs.