Receipt

Struct Receipt 

pub struct Receipt { /* private fields */ }
A receipt with applied and unapplied amounts.

Implementations

Source

impl Receipt

pub fn new( number: ReceiptNumber, received_at: ReceivedAt, applied_amount: AppliedAmount, unapplied_amount: UnappliedAmount, ) -> Result<Self, ReceiptError>

Creates a receipt and validates that applied and unapplied amounts use the same currency.

Errors

Returns ReceiptError::Money when applied and unapplied amounts cannot be added.

pub const fn number(&self) -> &ReceiptNumber

Returns the receipt number.

pub const fn received_at(&self) -> &ReceivedAt

Returns the received timestamp.

pub const fn applied_amount(&self) -> &AppliedAmount

Returns the applied amount.

pub const fn unapplied_amount(&self) -> &UnappliedAmount

Returns the unapplied amount.

pub const fn status(&self) -> ReceiptStatus

Returns the receipt status.

pub fn total_received(&self) -> Result<Money, ReceiptError>

Returns the total received amount.

Errors

Returns ReceiptError::Money when applied and unapplied amounts cannot be added.