Struct IncidenceMatrix
pub struct IncidenceMatrix { /* private fields */ }Expand description
A dense incidence matrix.
Implementations
impl IncidenceMatrix
impl IncidenceMatrix
pub fn new(
point_count: usize,
line_count: usize,
entries: Vec<bool>,
) -> Option<IncidenceMatrix>
pub fn new( point_count: usize, line_count: usize, entries: Vec<bool>, ) -> Option<IncidenceMatrix>
Creates a dense incidence matrix when the entry count matches point_count * line_count.
pub const fn point_count(&self) -> usize
pub const fn point_count(&self) -> usize
Returns the point count.
pub const fn line_count(&self) -> usize
pub const fn line_count(&self) -> usize
Returns the line count.
pub fn is_incident(&self, point: usize, line: usize) -> Option<bool>
pub fn is_incident(&self, point: usize, line: usize) -> Option<bool>
Returns whether a point is incident with a line.