Struct Dimension
pub struct Dimension(/* private fields */);Expand description
A positive spatial dimension count.
Implementations
impl Dimension
impl Dimension
pub const fn new_unchecked(value: usize) -> Dimension
pub const fn new_unchecked(value: usize) -> Dimension
Creates a dimension count without checking whether it is positive.
pub const fn is_spatial(self) -> bool
pub const fn is_spatial(self) -> bool
Returns true for dimensions commonly used as spatial geometry.