IncidenceMatrix

Struct IncidenceMatrix 

pub struct IncidenceMatrix { /* private fields */ }
A dense incidence matrix.

Implementations

Source

impl IncidenceMatrix

pub fn new( point_count: usize, line_count: usize, entries: Vec<bool>, ) -> Option<Self>

Creates a dense incidence matrix when the entry count matches point_count * line_count.

pub const fn point_count(&self) -> usize

Returns the point count.

pub const fn line_count(&self) -> usize

Returns the line count.

pub fn is_incident(&self, point: usize, line: usize) -> Option<bool>

Returns whether a point is incident with a line.