format_prefixed_id

Function format_prefixed_id 

pub fn format_prefixed_id(
    prefix: &IdPrefix,
    value: &str,
) -> Result<String, IdPrefixError>
Formats a prefix and value into the canonical prefix_value representation.

Errors

Returns IdPrefixError::EmptyValue when the trimmed value is empty and IdPrefixError::InvalidValueCharacter when it contains unsupported characters.