pub fn best_locale_match<I, S>(
requested: &str,
available: I,
) -> Option<LocaleMatch>Expand description
Finds the best available locale for a requested locale.
pub fn best_locale_match<I, S>(
requested: &str,
available: I,
) -> Option<LocaleMatch>Finds the best available locale for a requested locale.