elastic_deformation

Function elastic_deformation 

pub fn elastic_deformation(
    force_newtons: f64,
    length_m: f64,
    area_m2: f64,
    modulus_pa: f64,
) -> Result<f64, ElasticityError>
Computes axial elastic deformation.

Errors

Returns an ElasticityError when any input is not finite, or when length, area, or modulus is less than or equal to zero.