Aabb2

Struct Aabb2 

pub struct Aabb2 { /* private fields */ }
An axis-aligned bounding box represented by inclusive minimum and maximum corners.

Implementations

Source

impl Aabb2

pub fn try_new(min: Point2, max: Point2) -> Result<Self, GeometryError>

Creates a validated axis-aligned bounding box from ordered corners.

Errors

Returns GeometryError::NonFiniteComponent when either corner contains a non-finite coordinate.

Returns GeometryError::InvalidBounds when min is greater than max on either axis.

Examples
use use_geometry::{Aabb2, GeometryError, Point2};

let bounds = Aabb2::try_new(Point2::new(1.0, 2.0), Point2::new(4.0, 6.0))?;
assert_eq!(bounds.center(), Point2::new(2.5, 4.0));
pub const fn from_points(a: Point2, b: Point2) -> Self

Creates a bounding box from any two corners, normalizing axis order.

Examples
use use_geometry::{Aabb2, Point2};

let bounds = Aabb2::from_points(Point2::new(4.0, 1.0), Point2::new(1.0, 3.0));

assert_eq!(bounds.min(), Point2::new(1.0, 1.0));
assert_eq!(bounds.max(), Point2::new(4.0, 3.0));
pub const fn min(&self) -> Point2

Returns the inclusive minimum corner.

pub const fn max(&self) -> Point2

Returns the inclusive maximum corner.

pub fn width(&self) -> f64

Returns the box width.

pub fn height(&self) -> f64

Returns the box height.

pub const fn center(&self) -> Point2

Returns the box center.

pub fn area(&self) -> f64

Returns the box area.

pub fn contains_point(&self, point: Point2) -> bool

Returns true when point lies inside or on the boundary.

pub fn contains_point_with_tolerance( &self, point: Point2, tolerance: f64, ) -> Result<bool, GeometryError>

Returns true when point lies inside the box expanded by tolerance.

Errors

Returns GeometryError::NonFiniteTolerance when tolerance is NaN or infinite.

Returns GeometryError::NegativeTolerance when tolerance is negative.

Examples
use use_geometry::{Aabb2, GeometryError, Point2};

let bounds = Aabb2::from_points(Point2::new(1.0, 1.0), Point2::new(4.0, 3.0));
assert!(bounds.contains_point_with_tolerance(Point2::new(4.25, 3.0), 0.25)?);
pub fn is_degenerate(&self) -> bool

Returns true when the box has zero width or height.

pub fn is_degenerate_with_tolerance( &self, tolerance: f64, ) -> Result<bool, GeometryError>

Returns true when the box width or height is within tolerance of zero.

Errors

Returns GeometryError::NonFiniteTolerance when tolerance is NaN or infinite.

Returns GeometryError::NegativeTolerance when tolerance is negative.