Enum StatisticsError
pub enum StatisticsError {
EmptyInput,
InsufficientData {
needed: usize,
actual: usize,
},
TooManyValues {
actual: usize,
},
}Expand description
Errors returned by statistics helpers when the input cannot support the requested summary.
Variants
EmptyInput
The input slice was empty.
InsufficientData
The input slice does not contain enough values for the requested operation.
TooManyValues
The input slice is too large to convert its length into an exact f64 count.