checked_product_factorials

Function checked_product_factorials 

pub fn checked_product_factorials(values: &[u64]) -> Result<u128, GeodeError>
Returns the checked product of each factorial in values.

Errors

Returns GeodeError::ArithmeticOverflow when any constituent factorial or the final product no longer fits in u128.