pub fn relative_eq(a: f64, b: f64, epsilon: f64) -> boolExpand description
Returns true when a and b are within a relative epsilon.
Near zero, this falls back to an absolute comparison by using a scale
factor of at least 1.0. NaN never compares equal. Equal infinities
compare equal.