pub const fn supports_transparency(format: ImageFormat) -> boolExpand description
Returns true when the format can commonly carry transparency.
pub const fn supports_transparency(format: ImageFormat) -> boolReturns true when the format can commonly carry transparency.