Struct CloudLayer
pub struct CloudLayer { /* private fields */ }Expand description
A descriptive cloud layer built from kind, cover, and optional base.
Implementations
impl CloudLayer
impl CloudLayer
pub fn new(kind: CloudKind, cover: CloudCover) -> CloudLayer
pub fn new(kind: CloudKind, cover: CloudCover) -> CloudLayer
Creates a cloud layer from cloud kind and cover.
pub fn with_base(self, base: CloudBase) -> CloudLayer
pub fn with_base(self, base: CloudBase) -> CloudLayer
Adds a cloud base to the layer.
pub fn cover(&self) -> CloudCover
pub fn cover(&self) -> CloudCover
Returns the cloud cover.