pub fn is_alias_record(record_type: DnsRecordType) -> boolExpand description
Returns true when the record type stores an alias target.
pub fn is_alias_record(record_type: DnsRecordType) -> boolReturns true when the record type stores an alias target.