pub fn classify_wavelength_nm(wavelength_nm: f64) -> Option<SpectralBand>Expand description
Classifies a wavelength in nanometers into a coarse spectral band.
pub fn classify_wavelength_nm(wavelength_nm: f64) -> Option<SpectralBand>Classifies a wavelength in nanometers into a coarse spectral band.