axial_stiffness

Function axial_stiffness 

pub fn axial_stiffness(
    area: f64,
    youngs_modulus: f64,
    length: f64,
) -> Option<f64>
Computes axial stiffness of a uniform elastic bar.

Formula: k = AE / L.

Returns None when area is negative, youngs_modulus is negative, length is less than or equal to zero, or when any input or result is not finite.