pub fn change_in_length(strain: f64, original_length: f64) -> Option<f64>Expand description
Computes change in length from strain and original length.
Formula: ΔL = εL0.
Returns None when original_length is negative or when any input or result is not finite.