force_from_axial_deformation

Function force_from_axial_deformation 

pub fn force_from_axial_deformation(
    deformation: f64,
    length: f64,
    area: f64,
    youngs_modulus: f64,
) -> Option<f64>
Computes force from axial deformation of a uniform elastic bar.

Formula: F = δAE / L.

Returns None when length is less than or equal to zero, area is negative, youngs_modulus is negative, or when any input or result is not finite.