shear_strain_from_modulus

Function shear_strain_from_modulus 

pub fn shear_strain_from_modulus(
    shear_stress: f64,
    shear_modulus: f64,
) -> Option<f64>
Computes shear strain from shear stress and shear modulus.

Formula: γ = τ / G.

Returns None when shear_modulus is less than or equal to zero or when any input or result is not finite.