magnetic_flux

Function magnetic_flux 

pub fn magnetic_flux(
    magnetic_flux_density: f64,
    area: f64,
    angle_radians: f64,
) -> Option<f64>
Computes magnetic flux through an area.

Formula: Φ = B * A * cos(theta)

Returns None when area is negative, when any input is not finite, or when the computed result is not finite.

Examples

use use_magnetism::magnetic_flux;

assert_eq!(magnetic_flux(2.0, 3.0, 0.0), Some(6.0));