pub fn elliptical_orbital_period(mu: f64, semi_major_axis: f64) -> Option<f64>Expand description
Computes the orbital period for an elliptical orbit.
Formula: T = 2π * sqrt(a³ / μ)
Returns None when mu is less than or equal to zero, when semi_major_axis is less than
or equal to zero, or when the input or result is not finite.