orbital_radius_from_period

Function orbital_radius_from_period 

pub fn orbital_radius_from_period(mu: f64, period: f64) -> Option<f64>
Computes the circular orbital radius from an orbital period.

Formula: r = cbrt(μ * (T / 2π)²)

Returns None when mu is less than or equal to zero, when period is less than or equal to zero, or when the input or result is not finite.