pub fn source_mass_from_gravitational_parameter(mu: f64) -> Option<f64>Expand description
Computes the source mass from a standard gravitational parameter.
Formula: M = μ / G
Returns None when mu is negative, when the input is not finite, or when the result is not
finite.