Function bulk_modulus_from_youngs_and_poisson
pub fn bulk_modulus_from_youngs_and_poisson(
youngs_modulus: f64,
poisson_ratio: f64,
) -> Option<f64>Expand description
Computes bulk modulus from Young’s modulus and Poisson’s ratio.
Formula: K = E / (3 * (1 - 2ν)).
Returns None when youngs_modulus is negative, when the denominator is less than or equal
to zero, or when any input or result is not finite.