Function final_kinetic_energy_from_work
pub fn final_kinetic_energy_from_work(
initial_kinetic_energy: f64,
work: f64,
) -> Option<f64>Expand description
Computes final kinetic energy from an initial kinetic energy and applied work.
Formula: KE_final = KE_initial + W
Returns None when initial_kinetic_energy is negative, when any input is not finite, when
the computed result is negative, or when the computed result is not finite.