pub const fn has_rest_mass(kind: ParticleKind) -> Option<bool>Expand description
Returns whether kind has nonzero rest mass when that metadata is modeled here.
pub const fn has_rest_mass(kind: ParticleKind) -> Option<bool>Returns whether kind has nonzero rest mass when that metadata is modeled here.