rest_mass_from_momentum_speed

Function rest_mass_from_momentum_speed 

pub fn rest_mass_from_momentum_speed(
    momentum: f64,
    velocity: f64,
) -> Option<f64>
Computes rest mass from relativistic momentum and velocity using m = p / (γv).

Returns None when velocity is zero, when velocity is not finite or has a magnitude greater than or equal to the speed of light, when momentum is not finite, or when the computed rest mass is negative or not finite.