rotation_rod_moment_of_inertia_about_center

Function rotation_rod_moment_of_inertia_about_center 

pub fn rotation_rod_moment_of_inertia_about_center(
    mass: f64,
    length: f64,
) -> Option<f64>
Computes rod moment of inertia about its center using I = (1 / 12)mL².

Returns None when mass or length is negative, when any input is not finite, or when the computed moment of inertia is not finite.