Function two_body_total_momentum
pub fn two_body_total_momentum(
mass_a: f64,
velocity_a: f64,
mass_b: f64,
velocity_b: f64,
) -> Option<f64>Expand description
Computes the total momentum of two moving bodies using p_total = m1v1 + m2v2.
Returns None when either mass is negative, when any input is not finite, or when the total
momentum is not finite.