youngs_modulus_from_shear_and_poisson

Function youngs_modulus_from_shear_and_poisson 

pub fn youngs_modulus_from_shear_and_poisson(
    shear_modulus: f64,
    poisson_ratio: f64,
) -> Option<f64>
Computes Young’s modulus from shear modulus and Poisson’s ratio.

Formula: E = 2G(1 + ν).

Returns None when shear_modulus is negative, when the result is negative, or when any input or result is not finite.