angular_velocity_from_rotational_kinetic_energy

Function angular_velocity_from_rotational_kinetic_energy 

pub fn angular_velocity_from_rotational_kinetic_energy(
    rotational_kinetic_energy: f64,
    moment_of_inertia: f64,
) -> Option<f64>
Computes angular velocity from rotational kinetic energy using ω = sqrt(2KE / I).

Returns the non-negative principal value when successful. Returns None when rotational kinetic energy is negative, when moment_of_inertia is less than or equal to zero, when any input is not finite, or when the computed angular velocity is not finite.