Function energy_momentum_relation
pub fn energy_momentum_relation(rest_mass: f64, momentum: f64) -> Option<f64>Expand description
Computes total energy from rest mass and momentum using E = sqrt((pc)² + (mc²)²).
Returns None when rest_mass is negative or not finite, when momentum is not finite, or
when the computed energy is not finite.