Function hohmann_delta_v_2
pub fn hohmann_delta_v_2(
mu: f64,
radius_initial: f64,
radius_final: f64,
) -> Option<f64>Expand description
Computes the second burn for a Hohmann transfer.
Formula: Δv2 = sqrt(μ/r2) * (1 - sqrt(2r1 / (r1 + r2)))
Returns None when mu is less than or equal to zero, when either radius is less than or
equal to zero, or when the input or result is not finite.