hollow_sphere_moment_of_inertia

Function hollow_sphere_moment_of_inertia 

pub fn hollow_sphere_moment_of_inertia(mass: f64, radius: f64) -> Option<f64>
Computes hollow-sphere moment of inertia using I = (2 / 3)mr².

Returns None when mass or radius is negative, when any input is not finite, or when the computed moment of inertia is not finite.