Function initial_kinetic_energy_from_work
pub fn initial_kinetic_energy_from_work(
final_kinetic_energy: f64,
work: f64,
) -> Option<f64>Expand description
Computes initial kinetic energy from a final kinetic energy and applied work.
Formula: KE_initial = KE_final - W
Returns None when final_kinetic_energy is negative, when any input is not finite, when
the computed result is negative, or when the computed result is not finite.