Function rotation_point_mass_moment_of_inertia
pub fn rotation_point_mass_moment_of_inertia(
mass: f64,
radius: f64,
) -> Option<f64>Expand description
Computes point-mass moment of inertia using I = mr².
Returns None when mass or radius is negative, when any input is not finite, or when the
computed moment of inertia is not finite.