rotation_rod_moment_of_inertia_about_end

Function rotation_rod_moment_of_inertia_about_end 

pub fn rotation_rod_moment_of_inertia_about_end(
    mass: f64,
    length: f64,
) -> Option<f64>
Computes rod moment of inertia about one end using I = (1 / 3)mL².

Returns None when mass or length is negative, when any input is not finite, or when the computed moment of inertia is not finite.