strain_from_youngs_modulus

Function strain_from_youngs_modulus 

pub fn strain_from_youngs_modulus(
    stress: f64,
    youngs_modulus: f64,
) -> Option<f64>
Computes strain from stress and Young’s modulus.

Formula: ε = σ / E.

Returns None when youngs_modulus is less than or equal to zero or when any input or result is not finite.