Struct Fluid
pub struct Fluid {
pub density: f64,
pub dynamic_viscosity: Option<f64>,
}Expand description
A simple fluid model with density and optional dynamic viscosity.
Fields
density: f64dynamic_viscosity: Option<f64>Implementations
impl Fluid
impl Fluid
pub fn new(density: f64) -> Option<Fluid>
pub fn new(density: f64) -> Option<Fluid>
Creates a fluid from density when the density is non-negative and finite.
pub fn with_dynamic_viscosity(
density: f64,
dynamic_viscosity: f64,
) -> Option<Fluid>
pub fn with_dynamic_viscosity( density: f64, dynamic_viscosity: f64, ) -> Option<Fluid>
Creates a fluid from density and dynamic viscosity when both values are non-negative and finite.
pub fn buoyant_force(
&self,
displaced_volume: f64,
gravitational_acceleration: f64,
) -> Option<f64>
pub fn buoyant_force( &self, displaced_volume: f64, gravitational_acceleration: f64, ) -> Option<f64>
Computes buoyant force for a displaced volume in this fluid.
Examples
use use_fluid::Fluid;
let water = Fluid::new(1000.0).unwrap();
let force = water.buoyant_force(0.01, 9.80665).unwrap();
assert!((force - 98.0665).abs() < 1.0e-10);pub fn hydrostatic_pressure(
&self,
gravitational_acceleration: f64,
depth: f64,
) -> Option<f64>
pub fn hydrostatic_pressure( &self, gravitational_acceleration: f64, depth: f64, ) -> Option<f64>
Computes hydrostatic pressure at a depth in this fluid.
pub fn dynamic_pressure(&self, velocity: f64) -> Option<f64>
pub fn dynamic_pressure(&self, velocity: f64) -> Option<f64>
Computes dynamic pressure for this fluid at a given velocity.
pub fn reynolds_number(
&self,
velocity: f64,
characteristic_length: f64,
) -> Option<f64>
pub fn reynolds_number( &self, velocity: f64, characteristic_length: f64, ) -> Option<f64>
Computes Reynolds number for this fluid when dynamic viscosity is available.