MassProperties

Struct MassProperties 

pub struct MassProperties {
    pub mass: f64,
    pub moment_of_inertia: f64,
}
Mass and rotational inertia for a scalar rigid body.

Fields

mass: f64moment_of_inertia: f64

Implementations



impl MassProperties

pub fn new(mass: f64, moment_of_inertia: f64) -> Option<MassProperties>

Creates mass properties when both values are finite and non-negative.

pub fn point_mass(mass: f64, radius: f64) -> Option<MassProperties>

Creates mass properties for a point mass using I = mr².

pub fn solid_disk(mass: f64, radius: f64) -> Option<MassProperties>

Creates mass properties for a solid disk using I = 0.5mr².

pub fn thin_ring(mass: f64, radius: f64) -> Option<MassProperties>

Creates mass properties for a thin ring using I = mr².

pub fn solid_sphere(mass: f64, radius: f64) -> Option<MassProperties>

Creates mass properties for a solid sphere using I = (2 / 5)mr².

Examples
use use_rigidbody::MassProperties;

let props = MassProperties::solid_sphere(5.0, 2.0).unwrap();

assert_eq!(props.moment_of_inertia, 8.0);

pub fn hollow_sphere(mass: f64, radius: f64) -> Option<MassProperties>

Creates mass properties for a hollow sphere using I = (2 / 3)mr².

pub fn rod_about_center(mass: f64, length: f64) -> Option<MassProperties>

Creates mass properties for a rod about its center using I = (1 / 12)mL².

pub fn rod_about_end(mass: f64, length: f64) -> Option<MassProperties>

Creates mass properties for a rod about one end using I = (1 / 3)mL².

pub fn shifted_by_parallel_axis(self, distance: f64) -> Option<MassProperties>

Applies the parallel-axis theorem using I = I_cm + md².