Struct PointForce2D
pub struct PointForce2D {
pub position_x: f64,
pub position_y: f64,
pub force_x: f64,
pub force_y: f64,
}Expand description
A planar force applied at a position relative to a chosen moment point.
Fields
position_x: f64Horizontal position from the chosen origin.
position_y: f64Vertical position from the chosen origin.
force_x: f64Horizontal force component.
force_y: f64Vertical force component.
Implementations
impl PointForce2D
impl PointForce2D
pub fn new(
position_x: f64,
position_y: f64,
force_x: f64,
force_y: f64,
) -> Option<PointForce2D>
pub fn new( position_x: f64, position_y: f64, force_x: f64, force_y: f64, ) -> Option<PointForce2D>
Creates a new point force when all values are finite.
pub fn moment_about_origin(&self) -> Option<f64>
pub fn moment_about_origin(&self) -> Option<f64>
Returns the moment of this force about the origin.