DecayLaw

Struct DecayLaw 

pub struct DecayLaw {
    pub decay_constant: f64,
}
Simple exponential-decay law parameterized by a decay constant.

Fields

decay_constant: f64

Decay constant in inverse time units.

Implementations



impl DecayLaw

pub fn from_decay_constant(decay_constant: f64) -> Option<DecayLaw>

Creates a decay law from a non-negative, finite decay constant.

pub fn from_half_life(half_life: f64) -> Option<DecayLaw>

Creates a decay law from a positive, finite half-life.

pub fn half_life(&self) -> Option<f64>

Returns the half-life for this decay law.

pub fn mean_lifetime(&self) -> Option<f64>

Returns the mean lifetime for this decay law.

pub fn remaining_fraction(&self, time: f64) -> Option<f64>

Returns the remaining fraction after the given elapsed time.

pub fn remaining_quantity( &self, initial_quantity: f64, time: f64, ) -> Option<f64>

Returns the remaining quantity after the given elapsed time.

Examples
use use_nuclear::DecayLaw;

let decay_law = DecayLaw::from_half_life(10.0).ok_or("expected valid half-life")?;
let remaining = decay_law
    .remaining_quantity(100.0, 10.0)
    .ok_or("expected valid remaining quantity")?;

assert!((remaining - 50.0).abs() < 1.0e-12);

pub fn decayed_quantity(&self, initial_quantity: f64, time: f64) -> Option<f64>

Returns the decayed quantity after the given elapsed time.

pub fn activity(&self, number_of_nuclei: f64) -> Option<f64>

Returns the activity for the given number of nuclei.