Force2D

Struct Force2D 

pub struct Force2D {
    pub x: f64,
    pub y: f64,
}
A validated planar force value.

Fields

x: f64

Horizontal force component.

y: f64

Vertical force component.

Implementations



impl Force2D

pub fn new(x: f64, y: f64) -> Option<Force2D>

Creates a new planar force when both components are finite.

pub fn magnitude(&self) -> Option<f64>

Returns the magnitude of this force.

Examples
use use_statics::Force2D;

assert_eq!(Force2D::new(3.0, 4.0).and_then(|force| force.magnitude()), Some(5.0));

pub fn angle_radians(&self) -> Option<f64>

Returns the planar angle of this force in radians.