Struct MatterWave
pub struct MatterWave {
pub momentum: f64,
}Expand description
A lightweight matter-wave wrapper stored by momentum magnitude.
Fields
momentum: f64Momentum magnitude in kilogram meters per second.
Implementations
impl MatterWave
impl MatterWave
pub fn from_momentum(momentum: f64) -> Option<MatterWave>
pub fn from_momentum(momentum: f64) -> Option<MatterWave>
Creates a matter wave from a positive finite momentum magnitude.
pub fn from_mass_velocity(mass: f64, velocity: f64) -> Option<MatterWave>
pub fn from_mass_velocity(mass: f64, velocity: f64) -> Option<MatterWave>
Creates a matter wave from mass and velocity magnitude.
Examples
use use_quantum::{MatterWave, PLANCK_CONSTANT};
let wave = MatterWave::from_mass_velocity(2.0, 3.0).ok_or("expected valid inputs")?;
assert!((wave.wavelength().ok_or("expected wavelength")? - (PLANCK_CONSTANT / 6.0)).abs() < 1.0e-12);pub fn wavelength(&self) -> Option<f64>
pub fn wavelength(&self) -> Option<f64>
Returns the de Broglie wavelength in meters.