pub fn centripetal_acceleration_from_tangential_speed(
tangential_speed: f64,
radius: f64,
) -> Option<f64>Expand description
Computes centripetal acceleration using a_c = v² / r.
Returns None when radius is less than or equal to zero, when any input is not finite, or
when the computed acceleration is not finite.