tangential_speed

Function tangential_speed 

pub fn tangential_speed(angular_velocity: f64, radius: f64) -> Option<f64>
Computes tangential speed using v = ωr.

Returns None when radius is negative, when any input is not finite, or when the computed tangential speed is not finite.

Examples

use use_rotation::tangential_speed;

assert_eq!(tangential_speed(3.0, 2.0), Some(6.0));