pub struct PgExtensionName(/* private fields */);Expand description
PostgreSQL extension name primitive.
Implementations
Sourceimpl PgExtensionName
impl PgExtensionName
Sourcepub fn new(input: impl AsRef<str>) -> Result<Self, PgExtensionError>
pub fn new(input: impl AsRef<str>) -> Result<Self, PgExtensionError>
Creates an extension name label.
Errors
Returns PgExtensionError when the label is empty or contains unsupported characters.
Sourcepub fn uuid_ossp() -> Self
pub fn uuid_ossp() -> Self
Returns uuid-ossp as an extension name.
Panics
Panics only if the built-in uuid-ossp constant is changed to an invalid extension label.
Sourcepub fn pgcrypto() -> Self
pub fn pgcrypto() -> Self
Returns pgcrypto as an extension name.
Panics
Panics only if the built-in pgcrypto constant is changed to an invalid extension label.
Sourcepub fn citext() -> Self
pub fn citext() -> Self
Returns citext as an extension name.
Panics
Panics only if the built-in citext constant is changed to an invalid extension label.
Sourcepub fn hstore() -> Self
pub fn hstore() -> Self
Returns hstore as an extension name.
Panics
Panics only if the built-in hstore constant is changed to an invalid extension label.
Sourcepub fn postgis() -> Self
pub fn postgis() -> Self
Returns postgis as an extension name.
Panics
Panics only if the built-in postgis constant is changed to an invalid extension label.
Sourcepub fn pg_trgm() -> Self
pub fn pg_trgm() -> Self
Returns pg_trgm as an extension name.
Panics
Panics only if the built-in pg_trgm constant is changed to an invalid extension label.