Struct RobotsDirective
pub struct RobotsDirective { /* private fields */ }Expand description
A robots directive set suitable for meta content formatting.
Implementations
impl RobotsDirective
impl RobotsDirective
pub const fn new(
index: IndexDirective,
follow: FollowDirective,
) -> RobotsDirective
pub const fn new( index: IndexDirective, follow: FollowDirective, ) -> RobotsDirective
Creates a robots directive from index and follow directives.
pub const fn index_follow() -> RobotsDirective
pub const fn index_follow() -> RobotsDirective
Common index,follow directive.
pub const fn noindex_nofollow() -> RobotsDirective
pub const fn noindex_nofollow() -> RobotsDirective
Common noindex,nofollow directive.
pub const fn with_snippet(self, snippet: SnippetDirective) -> RobotsDirective
pub const fn with_snippet(self, snippet: SnippetDirective) -> RobotsDirective
Sets the snippet directive.
pub const fn with_archive(self, archive: ArchiveDirective) -> RobotsDirective
pub const fn with_archive(self, archive: ArchiveDirective) -> RobotsDirective
Sets the archive directive.
pub const fn index(&self) -> IndexDirective
pub const fn index(&self) -> IndexDirective
Returns the index directive.
pub const fn follow(&self) -> FollowDirective
pub const fn follow(&self) -> FollowDirective
Returns the follow directive.
pub fn to_meta_content(&self) -> String
pub fn to_meta_content(&self) -> String
Formats this directive as a robots meta content value.