Struct PythonVersion
pub struct PythonVersion { /* private fields */ }Expand description
Lightweight Python version metadata.
Implementations
impl PythonVersion
impl PythonVersion
pub fn new(
major: u16,
minor: Option<u16>,
patch: Option<u16>,
) -> Result<PythonVersion, PythonVersionParseError>
pub fn new( major: u16, minor: Option<u16>, patch: Option<u16>, ) -> Result<PythonVersion, PythonVersionParseError>
Creates Python version metadata.
Errors
Returns PythonVersionParseError::InvalidVersion when the major version is zero or
a patch component is present without a minor component.
pub const fn is_python3(&self) -> bool
pub const fn is_python3(&self) -> bool
Returns whether this version is in the Python 3 family.
pub fn is_prerelease_like(&self) -> bool
pub fn is_prerelease_like(&self) -> bool
Returns whether the parsed suffix looks like a prerelease marker.