BarError

Enum BarError 

pub enum BarError {
    InvalidPrice(MarketPriceError),
    NonFiniteVolume,
    NegativeVolume,
    InvalidHigh,
    InvalidLow,
}
Errors returned by bar construction.

Variants



InvalidPrice(MarketPriceError)

One of the price values was invalid.



NonFiniteVolume

Volume must be finite.



NegativeVolume

Volume must not be negative.



InvalidHigh

The high price was lower than open, low, or close.



InvalidLow

The low price was higher than open, high, or close.