ReturnError

Enum ReturnError 

pub enum ReturnError {
    NonFiniteReturn,
    NonFinitePrice {
        name: &'static str,
    },
    NonPositiveStartPrice,
    NegativeEndPrice,
    NonPositiveEndPrice,
}
Errors returned by return value construction and price-to-return helpers.

Variants



NonFiniteReturn

Return values must be finite.



NonFinitePrice

Price inputs must be finite.

Fields

name: &'static str


NonPositiveStartPrice

Start prices must be strictly positive.



NegativeEndPrice

End prices must not be negative for simple returns.



NonPositiveEndPrice

End prices must be strictly positive for log returns.