pub fn find_workspace_root(
start: impl AsRef<Path>,
) -> Result<WorkspaceRoot, CargoWorkspaceError>Expand description
Finds the nearest Cargo workspace root relative to a starting path.
pub fn find_workspace_root(
start: impl AsRef<Path>,
) -> Result<WorkspaceRoot, CargoWorkspaceError>Finds the nearest Cargo workspace root relative to a starting path.