pub const fn is_deprecated_like(algorithm: HashAlgorithm) -> boolExpand description
Returns true when a hash algorithm label is deprecated-like.
pub const fn is_deprecated_like(algorithm: HashAlgorithm) -> boolReturns true when a hash algorithm label is deprecated-like.