pub struct ChemicalReaction { /* private fields */ }Expand description
A chemical reaction with an equation, optional conditions, and classification labels.
Implementations
Sourceimpl ChemicalReaction
impl ChemicalReaction
Sourcepub const fn new() -> ChemicalReaction
pub const fn new() -> ChemicalReaction
Creates an empty reaction builder/value.
Sourcepub fn with_reactant<T>(self, reactant: T) -> ChemicalReaction
pub fn with_reactant<T>(self, reactant: T) -> ChemicalReaction
Adds a reactant and returns the updated reaction.
Sourcepub fn with_product<T>(self, product: T) -> ChemicalReaction
pub fn with_product<T>(self, product: T) -> ChemicalReaction
Adds a product and returns the updated reaction.
Sourcepub fn with_arrow(self, arrow: ReactionArrow) -> ChemicalReaction
pub fn with_arrow(self, arrow: ReactionArrow) -> ChemicalReaction
Sets the reaction arrow.
Sourcepub fn with_condition<T>(self, condition: T) -> ChemicalReactionwhere
T: Into<ReactionCondition>,
pub fn with_condition<T>(self, condition: T) -> ChemicalReactionwhere
T: Into<ReactionCondition>,
Adds a condition and returns the updated reaction.
Sourcepub fn with_kind(self, kind: ReactionKind) -> ChemicalReaction
pub fn with_kind(self, kind: ReactionKind) -> ChemicalReaction
Adds a kind label if it is not already present.
Sourcepub const fn equation(&self) -> &ReactionEquation
pub const fn equation(&self) -> &ReactionEquation
Returns the reaction equation.
Sourcepub const fn arrow(&self) -> ReactionArrow
pub const fn arrow(&self) -> ReactionArrow
Returns the reaction arrow.
Sourcepub const fn conditions(&self) -> &ReactionConditionSet
pub const fn conditions(&self) -> &ReactionConditionSet
Returns the reaction conditions.
Sourcepub fn kinds(&self) -> &[ReactionKind]
pub fn kinds(&self) -> &[ReactionKind]
Returns reaction kind labels in insertion order.
Sourcepub fn validate(&self) -> Result<(), ReactionValidationError>
pub fn validate(&self) -> Result<(), ReactionValidationError>
Validates the equation and condition descriptors.
Errors
Returns a ReactionValidationError when the equation is incomplete or a condition label
is empty.