Struct OxidationStateSet
pub struct OxidationStateSet { /* private fields */ }Expand description
A small insertion-order collection of oxidation-state assignments.
Implementations
impl OxidationStateSet
impl OxidationStateSet
pub const fn new() -> OxidationStateSet
pub const fn new() -> OxidationStateSet
Creates an empty oxidation-state set.
pub fn from_assignments(
assignments: impl IntoIterator<Item = OxidationStateAssignment>,
) -> OxidationStateSet
pub fn from_assignments( assignments: impl IntoIterator<Item = OxidationStateAssignment>, ) -> OxidationStateSet
Creates a set from assignments, replacing earlier entries with the same label.
pub fn insert(
&mut self,
assignment: OxidationStateAssignment,
) -> Option<OxidationStateAssignment>
pub fn insert( &mut self, assignment: OxidationStateAssignment, ) -> Option<OxidationStateAssignment>
Inserts an assignment and returns the previous assignment with the same label, if any.
pub fn get(&self, label: &str) -> Option<&OxidationStateAssignment>
pub fn get(&self, label: &str) -> Option<&OxidationStateAssignment>
Returns an assignment by label.
pub fn contains_label(&self, label: &str) -> bool
pub fn contains_label(&self, label: &str) -> bool
Returns true when an assignment for label exists.
pub fn iter(&self) -> Iter<'_, OxidationStateAssignment>
pub fn iter(&self) -> Iter<'_, OxidationStateAssignment>
Returns an iterator over assignments.