pub struct OxidationStateSet { /* private fields */ }Expand description
A small insertion-order collection of oxidation-state assignments.
Implementations
Sourceimpl OxidationStateSet
impl OxidationStateSet
Sourcepub fn from_assignments(
assignments: impl IntoIterator<Item = OxidationStateAssignment>,
) -> Self
pub fn from_assignments( assignments: impl IntoIterator<Item = OxidationStateAssignment>, ) -> Self
Creates a set from assignments, replacing earlier entries with the same label.
Sourcepub fn insert(
&mut self,
assignment: OxidationStateAssignment,
) -> Option<OxidationStateAssignment>
pub fn insert( &mut self, assignment: OxidationStateAssignment, ) -> Option<OxidationStateAssignment>
Inserts an assignment and returns the previous assignment with the same label, if any.
Sourcepub fn get(&self, label: &str) -> Option<&OxidationStateAssignment>
pub fn get(&self, label: &str) -> Option<&OxidationStateAssignment>
Returns an assignment by label.
Sourcepub fn contains_label(&self, label: &str) -> bool
pub fn contains_label(&self, label: &str) -> bool
Returns true when an assignment for label exists.
Sourcepub fn iter(&self) -> Iter<'_, OxidationStateAssignment>
pub fn iter(&self) -> Iter<'_, OxidationStateAssignment>
Returns an iterator over assignments.