Struct DiagnosticReport
pub struct DiagnosticReport { /* private fields */ }Expand description
An insertion-order collection of diagnostics.
Implementations
impl DiagnosticReport
impl DiagnosticReport
pub const fn new() -> DiagnosticReport
pub const fn new() -> DiagnosticReport
Creates an empty diagnostic report.
pub fn add(&mut self, diagnostic: Diagnostic)
pub fn add(&mut self, diagnostic: Diagnostic)
Adds a diagnostic to the end of the report.
pub fn diagnostics(&self) -> &[Diagnostic]
pub fn diagnostics(&self) -> &[Diagnostic]
Returns the diagnostics as a slice in insertion order.
pub fn iter(&self) -> Iter<'_, Diagnostic>
pub fn iter(&self) -> Iter<'_, Diagnostic>
Iterates diagnostics in insertion order.
pub fn count_by_level(&self, level: DiagnosticLevel) -> usize
pub fn count_by_level(&self, level: DiagnosticLevel) -> usize
Counts diagnostics with the exact provided level.
pub fn has_errors(&self) -> bool
pub fn has_errors(&self) -> bool
Returns true when the report contains an error or fatal diagnostic.
pub fn highest_severity(&self) -> Option<DiagnosticLevel>
pub fn highest_severity(&self) -> Option<DiagnosticLevel>
Returns the highest diagnostic severity in the report.
pub fn extend_report(&mut self, other: DiagnosticReport)
pub fn extend_report(&mut self, other: DiagnosticReport)
Extends this report with diagnostics from another report, preserving insertion order.