pub fn period_from_frequency(frequency: f64) -> Option<f64>Expand description
Computes period from frequency using T = 1 / f.
Returns None when frequency is less than or equal to zero, when the input is not finite,
or when the computed result is not finite.
Examples
use use_oscillation::period_from_frequency;
assert_eq!(period_from_frequency(2.0), Some(0.5));
assert_eq!(period_from_frequency(0.0), None);