Function hohmann_delta_v_1
pub fn hohmann_delta_v_1(
mu: f64,
radius_initial: f64,
radius_final: f64,
) -> Option<f64>Expand description
Computes the first burn for a Hohmann transfer.
Formula: Δv1 = sqrt(μ/r1) * (sqrt(2r2 / (r1 + r2)) - 1)
Returns None when mu is less than or equal to zero, when either radius is less than or
equal to zero, or when the input or result is not finite.