Function specific_orbital_energy
pub fn specific_orbital_energy(
speed: f64,
mu: f64,
distance: f64,
) -> Option<f64>Expand description
Computes specific orbital energy.
Formula: ε = v² / 2 - μ / r
Returns None when mu is negative, when distance is less than or equal to zero, or when
the input or result is not finite.