Function is_valid_coulomb_logarithm
pub fn is_valid_coulomb_logarithm(coulomb_logarithm: f64) -> boolExpand description
Returns whether a Coulomb logarithm value is finite and positive.
Detailed collisional plasma models and collision-frequency formulas are intentionally out of scope for this crate.