Function volumetric_flow_rate
pub fn volumetric_flow_rate(area: f64, velocity: f64) -> Option<f64>Expand description
Computes volumetric flow rate from area and flow velocity.
Formula: Q = A * v
Returns None when area is negative, when either input is not finite, or when the
computed result is not finite.
Examples
use use_fluid::volumetric_flow_rate;
assert_eq!(volumetric_flow_rate(2.0, 3.0), Some(6.0));
assert_eq!(volumetric_flow_rate(2.0, -3.0), Some(-6.0));